from distutils.core import setup
setup(
    name='Liyi', # 对外我们模块的名字
    version='1.0', # 版本号
    description='这是第一个对外发布的模块，测试哦', #描述
    author='Liyi', # 作者
    author_email='2307758843@qq.com',
    py_modules=['Liyi.demo1','Liyi.demo2'] # 要发布的模块
 )